==> cloudrail_knowledge-0.0.70b3-py3-none-any.whl: cloudrail/knowledge/context/azure/webapp/azure_app_service_config.py <==
from typing import Optional, List

from cloudrail.knowledge.context.azure.azure_resource import AzureResource
from cloudrail.knowledge.context.azure.constants.azure_resource_type import AzureResourceType
from cloudrail.knowledge.context.azure.webapp.auth_settings import AuthSettings
from cloudrail.knowledge.context.azure.webapp.constants import FtpsState


class AzureAppServiceConfig(AzureResource):
    """
        Attributes:
            name: The name of the AppService to which this config belongs.
            ftps_state: The FTPS state defined in this config. Either AllAllowed, FTPSOnly or Disabled.
            auth_settings: Function app authentication settings.
            minimum_tls_version: The minimum supported TLS version for the function app.
    """

    def __init__(self, name, ftps_state: FtpsState, auth_settings: AuthSettings, minimum_tls_version: str) -> None:
        super().__init__(AzureResourceType.NONE)
        self.name: str = name
        self.ftps_state: FtpsState = ftps_state or FtpsState.ALL_ALLOWED
        self.auth_settings: AuthSettings = auth_settings or AuthSettings()
        self.minimum_tls_version: str = minimum_tls_version or '1.2'

    def get_keys(self) -> List[str]:
        return [self.get_name()]

    def get_name(self) -> str:
        return self.name

    def get_cloud_resource_url(self) -> Optional[str]:
        return f'https://portal.azure.com/#@{self.tenant_id}/resource/subscriptions/{self.subscription_id}/resourceGroups/' \
               f'{self.resource_group_name}/providers/Microsoft.Web/sites/{self.name}/configuration'

    @property
    def is_tagable(self) -> bool:
        return False

    @staticmethod
    def is_standalone() -> bool:
        return False

==> cloudrail_knowledge-0.0.71b1-py3-none-any.whl: cloudrail/knowledge/context/azure/webapp/azure_app_service_config.py <==
from typing import Optional, List

from cloudrail.knowledge.context.azure.azure_resource import AzureResource
from cloudrail.knowledge.context.azure.constants.azure_resource_type import AzureResourceType
from cloudrail.knowledge.context.azure.webapp.auth_settings import AuthSettings
from cloudrail.knowledge.context.azure.webapp.constants import FtpsState


class AzureAppServiceConfig(AzureResource):
    """
        Attributes:
            name: The name of the AppService to which this config belongs.
            ftps_state: The FTPS state defined in this config. Either AllAllowed, FTPSOnly or Disabled.
            auth_settings: App service authentication settings.
            minimum_tls_version: The minimum supported TLS version for the function app.
    """

    def __init__(self, name, ftps_state: FtpsState, auth_settings: AuthSettings, minimum_tls_version: str) -> None:
        super().__init__(AzureResourceType.NONE)
        self.name: str = name
        self.ftps_state: FtpsState = ftps_state
        self.auth_settings: AuthSettings = auth_settings
        self.minimum_tls_version: str = minimum_tls_version

    def get_keys(self) -> List[str]:
        return [self.get_name()]

    def get_name(self) -> str:
        return self.name

    def get_cloud_resource_url(self) -> Optional[str]:
        return f'https://portal.azure.com/#@{self.tenant_id}/resource/subscriptions/{self.subscription_id}/resourceGroups/' \
               f'{self.resource_group_name}/providers/Microsoft.Web/sites/{self.name}/configuration'

    @property
    def is_tagable(self) -> bool:
        return False

    @staticmethod
    def is_standalone() -> bool:
        return False
